package com.example.composevideo

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Surface
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.DisposableEffect
import androidx.compose.runtime.remember
import androidx.compose.ui.Modifier
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.viewinterop.AndroidView
import com.example.composevideo.ui.theme.ComposeVideoTheme
import com.google.android.exoplayer2.ExoPlayer
import com.google.android.exoplayer2.MediaItem
import com.google.android.exoplayer2.Player.REPEAT_MODE_OFF
import com.google.android.exoplayer2.Player.REPEAT_MODE_ONE
import com.google.android.exoplayer2.ui.StyledPlayerView

// https://stackoverflow.com/questions/76758583/android-jetpack-compose-how-to-show-a-mp4-video-as-an-animation
/*
    added to gradle
    implementation 'com.google.android.exoplayer:exoplayer:2.18.7'
*/

/*
    edit AndroidManifest if taking mp4 directly from Internet

    or

    add raw directory and place local mp4 files there
*/

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            ComposeVideoTheme {
                // A surface container using the 'background' color from the theme
                Surface(
                    modifier = Modifier.fillMaxSize(),
                    color = MaterialTheme.colorScheme.background
                ) {
                    ExoplayerExample()
                }
            }
        }
    }
}

@Composable
fun ExoplayerExample() {

    val context = LocalContext.current

    val mediaItem = MediaItem.Builder()
        // if video is from web add INTERNET PERMISSION in AndroidManifest
        .setUri("http://commondatastorage.googleapis.com/gtv-videos-bucket/sample/BigBuckBunny.mp4")
        //.setUri("android.resource://" + "com.example.composevideo" + "/" + R.raw.crocodile)
        //.setUri("android.resource://" + context.packageName + "/" + R.raw.crocodile)
        .build()
    val exoPlayer = remember(context, mediaItem) {
        ExoPlayer.Builder(context)
            .build()
            .also { exoPlayer ->
                exoPlayer.setMediaItem(mediaItem)
                exoPlayer.prepare()
                //exoPlayer.playWhenReady = false  // user starts
                exoPlayer.playWhenReady = true     // starts on own
                // exoPlayer.repeatMode = REPEAT_MODE_OFF  // once and done
                exoPlayer.repeatMode = REPEAT_MODE_ONE   // loops
            }
    }

    DisposableEffect(
        AndroidView(factory = {
            StyledPlayerView(context).apply {
                player = exoPlayer
            }
        })
    ) {
        onDispose { exoPlayer.release() }
    }

}
